| Title: | Model Wrappers for Projection Methods |
|---|---|
| Description: | Bindings for additional regression models for use with the 'parsnip' package, including ordinary and spare partial least squares models for regression and classification (Rohart et al (2017) <doi:10.1371/journal.pcbi.1005752>). |
| Authors: | Max Kuhn [aut, cre] (ORCID: <https://orcid.org/0000-0003-2402-136X>), Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>) |
| Maintainer: | Max Kuhn <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0.9000 |
| Built: | 2026-05-20 10:32:15 UTC |
| Source: | https://github.com/tidymodels/plsmod |
Model predictions across many sub-models
## S3 method for class ''_mixo_pls'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...) ## S3 method for class ''_mixo_spls'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...) ## S3 method for class ''_mixo_plsda'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...) ## S3 method for class ''_mixo_splsda'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...)## S3 method for class ''_mixo_pls'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...) ## S3 method for class ''_mixo_spls'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...) ## S3 method for class ''_mixo_plsda'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...) ## S3 method for class ''_mixo_splsda'' multi_predict(object, new_data, num_comp = NULL, type = NULL, ...)
object |
An object of class |
new_data |
A rectangular data object, such as a data frame. |
num_comp |
An integer vector for the number of PLS terms to retain. |
type |
A single character value or |
... |
Not currently used. |
Tidy methods for pls and spls objects
## S3 method for class 'mixo_pls' tidy(x, ...) ## S3 method for class 'mixo_spls' tidy(x, ...)## S3 method for class 'mixo_pls' tidy(x, ...) ## S3 method for class 'mixo_spls' tidy(x, ...)
x |
An object with class |
... |
Not currently used. |
A tibble with columns terms (the predictor names), value (the
loadings), type (either "predictors" or "outcomes"), and component (the
component number).